# The Isaura data store
A lake of precalculated properties of biomedical entities

This repository provides an interface to the precalculated data available from the Ersilia Model Hub. At the moment, Isaura is focused on chemical descriptors.
